==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/outputs/ConfigurationServiceGitRepositoryResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Git repository property payload for Application Configuration Service
 * @property caCertResourceId Resource Id of CA certificate for https URL of Git repository.
 * @property gitImplementation Git libraries used to support various repository providers
 * @property hostKey Public sshKey of git repository.
 * @property hostKeyAlgorithm SshKey algorithm of git repository.
 * @property label Label of the repository
 * @property name Name of the repository
 * @property password Password of git repository basic auth.
 * @property patterns Collection of patterns of the repository
 * @property privateKey Private sshKey algorithm of git repository.
 * @property searchPaths Searching path of the repository
 * @property strictHostKeyChecking Strict host key checking or not.
 * @property uri URI of the repository
 * @property username Username of git repository basic auth.
 */
public data class ConfigurationServiceGitRepositoryResponse(
    public val caCertResourceId: String? = null,
    public val gitImplementation: String? = null,
    public val hostKey: String? = null,
    public val hostKeyAlgorithm: String? = null,
    public val label: String,
    public val name: String,
    public val password: String? = null,
    public val patterns: List<String>,
    public val privateKey: String? = null,
    public val searchPaths: List<String>? = null,
    public val strictHostKeyChecking: Boolean? = null,
    public val uri: String,
    public val username: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.appplatform.outputs.ConfigurationServiceGitRepositoryResponse):
            ConfigurationServiceGitRepositoryResponse = ConfigurationServiceGitRepositoryResponse(
            caCertResourceId = javaType.caCertResourceId().map({ args0 -> args0 }).orElse(null),
            gitImplementation = javaType.gitImplementation().map({ args0 -> args0 }).orElse(null),
            hostKey = javaType.hostKey().map({ args0 -> args0 }).orElse(null),
            hostKeyAlgorithm = javaType.hostKeyAlgorithm().map({ args0 -> args0 }).orElse(null),
            label = javaType.label(),
            name = javaType.name(),
            password = javaType.password().map({ args0 -> args0 }).orElse(null),
            patterns = javaType.patterns().map({ args0 -> args0 }),
            privateKey = javaType.privateKey().map({ args0 -> args0 }).orElse(null),
            searchPaths = javaType.searchPaths().map({ args0 -> args0 }),
            strictHostKeyChecking = javaType.strictHostKeyChecking().map({ args0 -> args0 }).orElse(null),
            uri = javaType.uri(),
            username = javaType.username().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/outputs/ConfigurationServiceGitRepositoryResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Git repository property payload for Application Configuration Service
 * @property caCertResourceId Resource Id of CA certificate for https URL of Git repository.
 * @property gitImplementation Git libraries used to support various repository providers
 * @property hostKey Public sshKey of git repository.
 * @property hostKeyAlgorithm SshKey algorithm of git repository.
 * @property label Label of the repository
 * @property name Name of the repository
 * @property password Password of git repository basic auth.
 * @property patterns Collection of patterns of the repository
 * @property privateKey Private sshKey algorithm of git repository.
 * @property searchPaths Searching path of the repository
 * @property strictHostKeyChecking Strict host key checking or not.
 * @property uri URI of the repository
 * @property username Username of git repository basic auth.
 */
public data class ConfigurationServiceGitRepositoryResponse(
    public val caCertResourceId: String? = null,
    public val gitImplementation: String? = null,
    public val hostKey: String? = null,
    public val hostKeyAlgorithm: String? = null,
    public val label: String,
    public val name: String,
    public val password: String? = null,
    public val patterns: List<String>,
    public val privateKey: String? = null,
    public val searchPaths: List<String>? = null,
    public val strictHostKeyChecking: Boolean? = null,
    public val uri: String,
    public val username: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.appplatform.outputs.ConfigurationServiceGitRepositoryResponse): ConfigurationServiceGitRepositoryResponse = ConfigurationServiceGitRepositoryResponse(
            caCertResourceId = javaType.caCertResourceId().map({ args0 -> args0 }).orElse(null),
            gitImplementation = javaType.gitImplementation().map({ args0 -> args0 }).orElse(null),
            hostKey = javaType.hostKey().map({ args0 -> args0 }).orElse(null),
            hostKeyAlgorithm = javaType.hostKeyAlgorithm().map({ args0 -> args0 }).orElse(null),
            label = javaType.label(),
            name = javaType.name(),
            password = javaType.password().map({ args0 -> args0 }).orElse(null),
            patterns = javaType.patterns().map({ args0 -> args0 }),
            privateKey = javaType.privateKey().map({ args0 -> args0 }).orElse(null),
            searchPaths = javaType.searchPaths().map({ args0 -> args0 }),
            strictHostKeyChecking = javaType.strictHostKeyChecking().map({ args0 -> args0 }).orElse(null),
            uri = javaType.uri(),
            username = javaType.username().map({ args0 -> args0 }).orElse(null),
        )
    }
}
